@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import dataclasses
 import datetime
+import functools
 import logging
 import multiprocessing
 import weakref
@@ -9,18 +10,26 @@ from typing import *
 from weakref import ref
 
 from hippolyzer.lib.base.datatypes import UUID
+from hippolyzer.lib.base.message.message import Message
+from hippolyzer.lib.base.message.message_handler import MessageHandler
+from hippolyzer.lib.client.state import BaseClientSession
+from hippolyzer.lib.proxy.addons import AddonManager
 from hippolyzer.lib.proxy.circuit import ProxiedCircuit
 from hippolyzer.lib.proxy.http_asset_repo import HTTPAssetRepo
 from hippolyzer.lib.proxy.http_proxy import HTTPFlowContext, is_asset_server_cap_name, SerializedCapData
+from hippolyzer.lib.proxy.namecache import ProxyNameCache
+from hippolyzer.lib.proxy.object_manager import ProxyWorldObjectManager
 from hippolyzer.lib.proxy.region import ProxiedRegion, CapType
+from hippolyzer.lib.proxy.settings import ProxySettings
 
 if TYPE_CHECKING:
     from hippolyzer.lib.proxy.message_logger import BaseMessageLogger
+    from hippolyzer.lib.proxy.http_flow import HippoHTTPFlow
 
 
-class Session:
+class Session(BaseClientSession):
     def __init__(self, session_id, secure_session_id, agent_id, circuit_code,
-                 login_data=None, session_manager=None):
+                 session_manager: Optional[SessionManager], login_data=None):
         self.login_data = login_data or {}
         self.pending = True
         self.id: UUID = session_id
@@ -34,6 +43,9 @@ class Session:
         self.selected: SelectionModel = SelectionModel()
         self.regions: List[ProxiedRegion] = []
         self.started_at = datetime.datetime.now()
+        self.message_handler: MessageHandler[Message, str] = MessageHandler()
+        self.http_message_handler: MessageHandler[HippoHTTPFlow, str] = MessageHandler()
+        self.objects = ProxyWorldObjectManager(self, session_manager.settings, session_manager.name_cache)
         self._main_region = None
 
     @property
@@ -49,8 +61,8 @@ class Session:
             secure_session_id=UUID(login_data["secure_session_id"]),
             agent_id=UUID(login_data["agent_id"]),
             circuit_code=int(login_data["circuit_code"]),
-            login_data=login_data,
             session_manager=session_manager,
+            login_data=login_data,
         )
         appearance_service = login_data.get("agent_appearance_service")
         map_image_service = login_data.get("map-server-url")
@@ -61,6 +73,7 @@ class Session:
         # Login data also has details about the initial sim
         sess.register_region(
             circuit_addr=(login_data["sim_ip"], login_data["sim_port"]),
+            handle=(login_data["region_x"] << 32) | login_data["region_y"],
             seed_url=login_data["seed_capability"],
         )
         return sess
@@ -105,12 +118,26 @@ class Session:
                 return region
         return None
 
+    def region_by_handle(self, handle: int) -> Optional[ProxiedRegion]:
+        for region in self.regions:
+            if region.handle == handle:
+                return region
+        return None
+
     def open_circuit(self, near_addr, circuit_addr, transport):
         for region in self.regions:
             if region.circuit_addr == circuit_addr:
                 if not region.circuit or not region.circuit.is_alive:
+                    logging_hook = None
+                    if self.session_manager.message_logger:
+                        logging_hook = functools.partial(
+                            self.session_manager.message_logger.log_lludp_message,
+                            self,
+                            region,
+                        )
                     region.circuit = ProxiedCircuit(
-                        near_addr, circuit_addr, transport, region=region)
+                        near_addr, circuit_addr, transport, logging_hook=logging_hook)
+                    AddonManager.handle_circuit_created(self, region)
                     return True
                 if region.circuit and region.circuit.is_alive:
                     # Whatever, already open
@@ -136,7 +163,7 @@ class Session:
                 return CapData(cap_name, ref(region), ref(self), base_url, cap_type)
         return None
 
-    def tid_to_assetid(self, transaction_id: UUID):
+    def transaction_to_assetid(self, transaction_id: UUID):
         return UUID.combine(transaction_id, self.secure_session_id)
 
     def __repr__(self):
@@ -144,16 +171,22 @@ class Session:
 
 
 class SessionManager:
-    def __init__(self):
+    def __init__(self, settings: ProxySettings):
+        self.settings: ProxySettings = settings
         self.sessions: List[Session] = []
         self.shutdown_signal = multiprocessing.Event()
         self.flow_context = HTTPFlowContext()
         self.asset_repo = HTTPAssetRepo()
         self.message_logger: Optional[BaseMessageLogger] = None
         self.addon_ctx: Dict[str, Any] = {}
+        self.name_cache = ProxyNameCache()
 
     def create_session(self, login_data) -> Session:
         session = Session.from_login_data(login_data, self)
+        self.name_cache.create_subscriptions(
+            session.message_handler,
+            session.http_message_handler,
+        )
         self.sessions.append(session)
         logging.info("Created %r" % session)
         return session
@@ -168,6 +201,7 @@ class SessionManager:
 
     def close_session(self, session: Session):
         logging.info("Closed %r" % session)
+        session.objects.clear()
         self.sessions.remove(session)
 
     def resolve_cap(self, url: str) -> Optional["CapData"]:
